@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Contact;
 
 BEGIN {
-    $WWW::Google::Contacts::Contact::VERSION = '0.16';
+    $WWW::Google::Contacts::Contact::VERSION = '0.17';
 }
 
 use Moose;
@@ -386,6 +386,11 @@ sub add_email {
     push @{ $self->email }, to_Email($email);
 }
 
+sub add_user_defined {
+    my ( $self, $user_def ) = @_;
+    push @{ $self->user_defined }, to_UserDefined($user_def);
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
