@@ -1,13 +1,17 @@
 package WWW::Google::Contacts::Type::Base;
 
 BEGIN {
-    $WWW::Google::Contacts::Type::Base::VERSION = '0.16';
+    $WWW::Google::Contacts::Type::Base::VERSION = '0.17';
 }
 
 use Moose;
 
 extends 'WWW::Google::Contacts::Base';
 
+sub search_field {
+    return undef;
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
